
from django.dispatch import Signal


# Nation signal
nation_data_updated = Signal()


# Application signal
app_data_updated = Signal()

# User signal
user_data_updated = Signal()

# Access signal
access_data_updated = Signal()